import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.5

Window {
    visible: true
    width: 640
    height: 480
    title: qsTr("TableView Scrolling")

    Rectangle {
        height: parent.height * .8
        width:  parent.width  * .8

        anchors.top: parent.top
        anchors.topMargin: parent.height * .05
        anchors.horizontalCenter: parent.horizontalCenter

        border.width: 1
        border.color: "black"

        TableView {
            id: tableView
            anchors.fill: parent

            topMargin: height * .1
            bottomMargin: height * .1

            clip: true

            delegate: Rectangle {
                implicitWidth: parent.width
                implicitHeight: tableView.height * .1
                border.width: 1
                border.color: "black"

                Text {
                    anchors.centerIn: parent
                    text: name
                }
            }

            ScrollBar.vertical: ScrollBar {
                id: scrollBar
                visible: scrollBar.policy === ScrollBar.AlwaysOn || (scrollBar.policy === ScrollBar.AsNeeded && scrollBar.size < 1.0)
                topPadding: tableView.topMargin
                bottomPadding: tableView.bottomMargin
                background: Rectangle {
                    color: "transparent"
                }

                contentItem: Rectangle {
                    implicitWidth: 6
                    implicitHeight: 6
                    radius: width / 2
                    color: "lightgray"
                }
            }
        }
    }

    Row {
        height: parent.height * .1
        width:  parent.width  * .8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: parent.height * .05
        anchors.horizontalCenter: parent.horizontalCenter

        spacing: parent.width * .05

        Button {
            height: parent.height
            width:  parent.width * .475

            text: "Model Full"

            onClicked: tableView.model = modelFull
        }

        Button {
            height: parent.height
            width:  parent.width * .475

            text: "Model Empty"

            onClicked: tableView.model = modelEmpty
        }
    }

    ListModel {
        id: modelFull

        ListElement { name: "Entry A"; }
        ListElement { name: "Entry B"; }
        ListElement { name: "Entry C"; }
        ListElement { name: "Entry D"; }
        ListElement { name: "Entry E"; }
        ListElement { name: "Entry F"; }
        ListElement { name: "Entry G"; }
        ListElement { name: "Entry H"; }
        ListElement { name: "Entry I"; }
        ListElement { name: "Entry J"; }
        ListElement { name: "Entry K"; }
        ListElement { name: "Entry L"; }
        ListElement { name: "Entry M"; }
        ListElement { name: "Entry N"; }
        ListElement { name: "Entry O"; }
        ListElement { name: "Entry P"; }
        ListElement { name: "Entry Q"; }
    }

    ListModel {
        id: modelEmpty
    }

}
